@@ -1,8 +1,8 @@
 #' @importFrom tidyr crossing
 #' @importFrom purrr flatten
 frame_simulation <- function(dg, pg, sim, summary_fun) {
-  # if summary_fun is NULL, names(summary_fun) is NULL and crossing ignores it.
-  ret <- tidyr::crossing(dg,
+  # if summary_fun is NULL, names(summary_fun) is NULL and expand_grid ignores it.
+  ret <- tidyr::expand_grid(dg,
     replications = seq_along(sim[[1]]),
     summary_fun = names(summary_fun), pg
   )
